@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,7 +26,7 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
  * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -433,7 +433,7 @@ public class LocaleNames_to extends OpenListResourceBundle {
             { "io", "lea faka\u02bbito" },
             { "is", "lea faka\u02bbaisilani" },
             { "it", "lea faka\u02bb\u012btali" },
-            { "iu", "lea faka\u02bbinuketituti" },
+            { "iu", "lea faka\u02bbinuket\u012btuti" },
             { "ja", "lea fakasiapani" },
             { "jv", "lea fakasava" },
             { "ka", "lea fakase\u014dsia" },
@@ -484,7 +484,7 @@ public class LocaleNames_to extends OpenListResourceBundle {
             { "oc", "lea faka\u02bbokitane" },
             { "oj", "lea faka\u02bbosipiu\u0101" },
             { "om", "lea faka\u02bbolomo" },
-            { "or", "lea faka-\u02bbotia" },
+            { "or", "lea faka\u02bbotia" },
             { "os", "lea faka\u02bbosetiki" },
             { "pa", "lea fakap\u016bnusapi" },
             { "pi", "lea fakap\u0101li" },
@@ -559,18 +559,21 @@ public class LocaleNames_to extends OpenListResourceBundle {
             { "aln", "lea faka\u02bbalap\u0113nia-keki" },
             { "alt", "lea faka\u02bbalitai-tonga" },
             { "ang", "lea fakap\u0101langi-motu\u02bba" },
+            { "ann", "lea faka\u02bbopolo" },
             { "anp", "lea faka\u02bbangika" },
             { "arc", "lea faka\u02bbal\u0101miti" },
             { "arn", "lea fakamapuse" },
             { "aro", "lea faka\u02bbalaona" },
             { "arp", "lea faka\u02bbalapaho" },
             { "arq", "lea faka\u02bbalepea-\u02bbaisilia" },
+            { "ars", "lea faka\u02bbalepea-n\u0101siti" },
             { "arw", "lea faka\u02bbalauaki" },
             { "ary", "lea faka\u02bbalepea-moloko" },
             { "arz", "lea faka\u02bbalepea-\u02bbisipite" },
             { "asa", "lea faka\u02bbasu" },
             { "ase", "lea faka\u02bbilonga-\u02bbamelika" },
             { "ast", "lea faka\u02bbasit\u016blia" },
+            { "atj", "lea faka\u02bbatikameku" },
             { "avk", "lea fakakotava" },
             { "awa", "lea faka\u02bbauati" },
             { "bal", "lea fakapalusi" },
@@ -621,11 +624,19 @@ public class LocaleNames_to extends OpenListResourceBundle {
             { "chr", "lea fakaselok\u012b" },
             { "chy", "lea fakaseiene" },
             { "ckb", "lea fakak\u016btisi-loloto" },
+            { "clc", "lea fakatisilik\u014dtini" },
             { "cop", "lea fakakopitika" },
             { "cps", "lea fakakapiseno" },
+            { "crg", "lea fakametisifi" },
             { "crh", "lea fakatoake-kilimea" },
+            { "crj", "lea fakakil\u012b-tongahahake" },
+            { "crk", "lea fakakil\u012b-toafa" },
+            { "crl", "lea fakakil\u012b-tokelauhahake" },
+            { "crm", "lea fakamose-kil\u012b" },
+            { "crr", "lea faka\u02bbalakonikuia-kalolina" },
             { "crs", "lea fakaseselua-falanis\u0113" },
             { "csb", "lea fakakasiupia" },
+            { "csw", "lea fakakil\u012b-ano" },
             { "dak", "lea fakatakota" },
             { "dar", "lea fakatalaku\u0101" },
             { "dav", "lea fakataita" },
@@ -689,6 +700,7 @@ public class LocaleNames_to extends OpenListResourceBundle {
             { "hai", "lea fakahaita" },
             { "hak", "lea fakasiaina-haka" },
             { "haw", "lea fakahauai\u02bbi" },
+            { "hax", "lea fakahaita-tonga" },
             { "hif", "lea fakahinit\u012b-fisi" },
             { "hil", "lea fakahilikainoni" },
             { "hit", "lea fakahitite" },
@@ -696,8 +708,10 @@ public class LocaleNames_to extends OpenListResourceBundle {
             { "hsb", "lea fakas\u014dpia-hake" },
             { "hsn", "lea fakasiaina-siangi" },
             { "hup", "lea fakahupa" },
+            { "hur", "lea fakahalikomele" },
             { "iba", "lea faka\u02bbipani" },
             { "ibb", "lea faka\u02bbipipio" },
+            { "ikt", "lea faka\u02bbinuket\u012btuti-k\u0101nata-hihifo" },
             { "ilo", "lea faka\u02bbiloko" },
             { "inh", "lea faka\u02bbingusi" },
             { "izh", "lea faka\u02bbingiliani" },
@@ -744,6 +758,7 @@ public class LocaleNames_to extends OpenListResourceBundle {
             { "ksh", "lea fakakolongia" },
             { "kum", "lea fakakumiki" },
             { "kut", "lea fakakutenai" },
+            { "kwk", "lea fakakuakuala" },
             { "lad", "lea fakalatino" },
             { "lag", "lea fakalangi" },
             { "lah", "lea fakal\u0101nita" },
@@ -751,12 +766,15 @@ public class LocaleNames_to extends OpenListResourceBundle {
             { "lez", "lea fakalesikia" },
             { "lfn", "lea fakakavakava-fo\u02bbou" },
             { "lij", "lea fakalikulia" },
+            { "lil", "lea fakalil\u014deti" },
             { "liv", "lea fakalivonia" },
             { "lkt", "lea fakalakota" },
             { "lmo", "lea fakalomip\u0101ti" },
             { "lol", "lea fakamongik\u014d" },
+            { "lou", "lea fakaluisiana" },
             { "loz", "lea fakalosi" },
             { "lrc", "lea fakaluli-tokelau" },
+            { "lsm", "lea fakas\u0101mia" },
             { "ltg", "lea fakalatakale" },
             { "lua", "lea fakalupa-lulua" },
             { "lui", "lea fakaluiseno" },
@@ -786,6 +804,7 @@ public class LocaleNames_to extends OpenListResourceBundle {
             { "min", "lea fakaminangikapau" },
             { "mnc", "lea fakamanis\u016b" },
             { "mni", "lea fakamanipuli" },
+            { "moe", "lea faka\u02bbinu\u02bbaimuni" },
             { "moh", "lea fakamohauki" },
             { "mos", "lea fakamosi" },
             { "mrj", "lea fakamali-hihifo" },
@@ -819,6 +838,11 @@ public class LocaleNames_to extends OpenListResourceBundle {
             { "nyn", "lea fakanianikole" },
             { "nyo", "lea fakaniolo" },
             { "nzi", "lea fakanesima" },
+            { "ojb", "lea faka\u02bbosipiu\u0101-tokelauhihifo" },
+            { "ojc", "lea faka\u02bbosipiu\u0101-loto" },
+            { "ojs", "lea fakakil\u012b-osi" },
+            { "ojw", "lea faka\u02bbosipiu\u0101-hihifo" },
+            { "oka", "lea faka-\u02bbokan\u0101kani" },
             { "osa", "lea faka\u02bbos\u0113se" },
             { "ota", "lea fakatoake-\u02bbotomani" },
             { "pag", "lea fakapangasinani" },
@@ -833,9 +857,11 @@ public class LocaleNames_to extends OpenListResourceBundle {
             { "peo", "lea fakap\u0113sia-motu\u02bba" },
             { "pfl", "lea fakasiamane-palatine" },
             { "phn", "lea fakafoinikia" },
+            { "pis", "lea fakapisini" },
             { "pms", "lea fakapiemonite" },
             { "pnt", "lea fakaponitiki" },
             { "pon", "lea fakaponap\u0113" },
+            { "pqm", "lea fakamaliseti-pasamakuoti" },
             { "prg", "lea fakapul\u016bsia" },
             { "pro", "lea fakapolovenisi-motu\u02bba" },
             { "quc", "lea fakak\u012bs\u0113" },
@@ -844,6 +870,7 @@ public class LocaleNames_to extends OpenListResourceBundle {
             { "rap", "lea fakalapanui" },
             { "rar", "lea fakalalotonga" },
             { "rgn", "lea fakalomaniolo" },
+            { "rhg", "lea fakalouhingia" },
             { "rif", "lea fakalifi" },
             { "rof", "lea fakalomip\u014d" },
             { "rom", "lea fakalomani" },
@@ -876,6 +903,7 @@ public class LocaleNames_to extends OpenListResourceBundle {
             { "shn", "lea fakasiani" },
             { "shu", "lea faka\u02bbalepea-s\u0101ti" },
             { "sid", "lea fakasitamo" },
+            { "slh", "lea fakalus\u016btisiti" },
             { "sli", "lea fakasilesia-hifo" },
             { "sly", "lea fakaselai\u0101" },
             { "sma", "lea fakasami-tonga" },
@@ -888,6 +916,7 @@ public class LocaleNames_to extends OpenListResourceBundle {
             { "srr", "lea fakas\u0113l\u0113le" },
             { "ssy", "lea fakasaho" },
             { "stq", "lea fakafilisia-sat\u0113lani" },
+            { "str", "lea fakasalisi-vahatokelau" },
             { "suk", "lea fakasukuma" },
             { "sus", "lea fakasus\u016b" },
             { "sux", "lea fakasumelia" },
@@ -895,11 +924,14 @@ public class LocaleNames_to extends OpenListResourceBundle {
             { "syc", "lea fakasuli\u0101i\u0101-mu\u02bba" },
             { "syr", "lea fakasuli\u0101i\u0101" },
             { "szl", "lea fakasilesia" },
+            { "tce", "lea fakatutisone-tonga" },
             { "tcy", "lea fakatulu" },
             { "tem", "lea fakatimen\u0113" },
             { "teo", "lea fakateso" },
             { "ter", "lea fakateleno" },
             { "tet", "lea fakatetumu" },
+            { "tgx", "lea fakat\u0101kisi" },
+            { "tht", "lea fakat\u0101lit\u0101ni" },
             { "tig", "lea fakatikil\u0113" },
             { "tiv", "lea fakativi" },
             { "tkl", "lea fakatokelau" },
@@ -909,11 +941,13 @@ public class LocaleNames_to extends OpenListResourceBundle {
             { "tly", "lea fakatalisi" },
             { "tmh", "lea fakatamasieki" },
             { "tog", "lea fakaniasa-tonga" },
+            { "tok", "lea fakatoki-pona" },
             { "tpi", "lea fakatoki-pisini" },
             { "tru", "lea fakatuloio" },
             { "trv", "lea fakataloko" },
             { "tsd", "lea fakasak\u014dnia" },
             { "tsi", "lea fakatis\u012bmisiani" },
+            { "ttm", "lea fakatutisone-tokelau" },
             { "ttt", "lea fakatati-moselemi" },
             { "tum", "lea fakatumepuka" },
             { "tvl", "lea fakat\u016bvalu" },
@@ -955,9 +989,11 @@ public class LocaleNames_to extends OpenListResourceBundle {
             { "zun", "lea fakasuni" },
             { "zxx", "\u02bbikai ha lea" },
             { "zza", "lea fakas\u0101s\u0101" },
+            { "Adlm", "tohinima faka\u02bbatilami" },
             { "Afak", "tohinima faka\u02bbafaka" },
             { "Aghb", "tohinima faka\u02bbalap\u0113nia-kaukasia" },
             { "Arab", "tohinima faka\u02bbalepea" },
+            { "Aran", "tohinima fakanasatal\u012bki" },
             { "Armi", "tohinima faka\u02bbal\u0101miti-\u02bbemipaea" },
             { "Armn", "tohinima faka\u02bb\u0101menia" },
             { "Avst", "tohinima faka\u02bbavesitani" },
@@ -1073,6 +1109,7 @@ public class LocaleNames_to extends OpenListResourceBundle {
             { "Plrd", "tohinima fakafon\u0113tiki-pol\u0101ti" },
             { "Prti", "tohinima fakap\u0101tia-tongi" },
             { "Rjng", "tohinima fakalesiangi" },
+            { "Rohg", "tohinima fakahanifi-lohingia" },
             { "Roro", "tohinima fakalongolongo" },
             { "Runr", "tohinima fakaluniki" },
             { "Samr", "tohinima fakasamalitane" },
@@ -1133,8 +1170,6 @@ public class LocaleNames_to extends OpenListResourceBundle {
             { "fr_CA", "lea fakafalanis\u0113-k\u0101nata" },
             { "fr_CH", "lea fakafalanis\u0113-suisilani" },
             { "nl_BE", "lea fakah\u014dlani-pelesiume" },
-            { "pt_BR", "lea fakapotukali-pal\u0101sili" },
-            { "pt_PT", "lea fakapotukali-\u02bbiulope" },
             { "ro_MD", "lea fakamolit\u0101via" },
             { "sw_CD", "lea fakasuahili-kongik\u014d" },
             { "ar_001", "lea faka\u02bbalepea (m\u0101mani)" },
@@ -1158,6 +1193,7 @@ public class LocaleNames_to extends OpenListResourceBundle {
             { "type.nu.arab", "fika faka\u02bbalepea" },
             { "type.nu.armn", "fika faka\u02bb\u0101menia" },
             { "type.nu.beng", "faka fakap\u0101ngil\u0101" },
+            { "type.nu.cakm", "fika fakakakema" },
             { "type.nu.deva", "fika fakatevan\u0101kal\u012b" },
             { "type.nu.ethi", "fika faka\u02bb\u012bti\u014dpia" },
             { "type.nu.geor", "fika fakase\u014dsia" },
@@ -1167,23 +1203,28 @@ public class LocaleNames_to extends OpenListResourceBundle {
             { "type.nu.hans", "fika fakasiaina fakafaingofua" },
             { "type.nu.hant", "fika fakasiaina tukufakaholo" },
             { "type.nu.hebr", "fika fakahepel\u016b" },
+            { "type.nu.java", "fika fakasava" },
             { "type.nu.jpan", "fika fakasiapani" },
             { "type.nu.khmr", "fika fakakamip\u014dtia" },
             { "type.nu.knda", "fika fakakanata" },
             { "type.nu.laoo", "fika fakalau" },
             { "type.nu.latn", "fika fakalatina" },
             { "type.nu.mlym", "fika fakamal\u0101ialami" },
+            { "type.nu.mtei", "fika fakametei-maieki" },
             { "type.nu.mymr", "fika fakapema" },
             { "type.nu.nkoo", "fika fakanik\u014d" },
+            { "type.nu.olck", "fika faka\u02bbolisiki" },
             { "type.nu.orya", "fika faka\u02bbotia" },
             { "type.nu.taml", "fika fakatamili tukufakaholo" },
             { "type.nu.telu", "fika fakateluku" },
             { "type.nu.thai", "fika fakatailani" },
             { "type.nu.tibt", "fika fakatipeti" },
+            { "type.nu.vaii", "fika fakavai" },
             { "type.ca.dangi", "fakataniki" },
             { "type.co.ducet", "\u02bbunik\u014dti" },
             { "type.lb.loose", "fesi\u02bbilaine ngaloku" },
             { "type.nu.roman", "fika fakaloma" },
+            { "type.ca.coptic", "fakakopitika" },
             { "type.ca.hebrew", "fakahepel\u016b" },
             { "type.ca.indian", "faka\u02bbinitia" },
             { "type.co.search", "fakakumi \u02bbi hono anga lahi" },
@@ -1216,6 +1257,8 @@ public class LocaleNames_to extends OpenListResourceBundle {
             { "type.co.phonebook", "fika telefoni" },
             { "type.co.traditional", "tukufakaholo" },
             { "type.ca.islamic-civil", "fakamohameti-sivile" },
+            { "type.ca.islamic-umalqura", "fakamohameti-\u02bbumalakula" },
+            { "type.ca.ethiopic-amete-alem", "faka\u02bb\u012bti\u014dpia-\u02bbamete-\u02bbalemi" },
         };
         return data;
     }
